<?php
$TRANSLATIONS = array(
"Invalid value supplied for %s" => "Неверное значение для %s",
"Saved" => "Сохранено",
"test email settings" => "тест настроек почты",
"If you received this email, the settings seem to be correct." => "Если вы получили это письмо, настройки верны.",
"A problem occurred while sending the e-mail. Please revisit your settings." => "Произошла ошибка при отправке сообщения электронной почты, пожалуйста, пожалуйста проверьте настройки.",
"Email sent" => "Письмо отправлено",
"You need to set your user email before being able to send test emails." => "Вы должны настроить свой e-mail пользователя прежде чем отправлять тестовые сообщения.",
"Send mode" => "Отправить сообщение",
"Encryption" => "Шифрование",
"Authentication method" => "Метод проверки подлинности",
"Unable to load list from App Store" => "Не удалось загрузить список из App Store",
"Authentication error" => "Ошибка аутентификации",
"Your full name has been changed." => "Ваше полное имя было изменено.",
"Unable to change full name" => "Невозможно изменить полное имя",
"Group already exists" => "Группа уже существует",
"Unable to add group" => "Невозможно добавить группу",
"Files decrypted successfully" => "Дешифрование файлов прошло успешно",
"Couldn't decrypt your files, please check your owncloud.log or ask your administrator" => "Ошибка при дешифровании файлов. Обратитесь к вашему системному администратору. Доп информация в owncloud.log",
"Couldn't decrypt your files, check your password and try again" => "Ошибка при дешифровании файлов. Проверьте Ваш пароль и повторите попытку",
"Encryption keys deleted permanently" => "Ключи шифрования перманентно удалены",
"Couldn't permanently delete your encryption keys, please check your owncloud.log or ask your administrator" => "Не получается удалить ваши ключи шифрования, пожалуйста проверьте файл owncloud.log или обратитесь к Администратору",
"Couldn't remove app." => "Невозможно удалить приложение.",
"Email saved" => "Email сохранен",
"Invalid email" => "Неправильный Email",
"Unable to delete group" => "Невозможно удалить группу",
"Unable to delete user" => "Невозможно удалить пользователя",
"Backups restored successfully" => "Резервная копия успешно восстановлена",
"Couldn't restore your encryption keys, please check your owncloud.log or ask your administrator" => "Не получается восстановить ваши ключи шифрования, пожалуйста проверьте файл owncloud.log или обратитесь к Администратору.",
"Language changed" => "Язык изменён",
"Invalid request" => "Неправильный запрос",
"Admins can't remove themself from the admin group" => "Администратор не может удалить сам себя из группы admin",
"Unable to add user to group %s" => "Невозможно добавить пользователя в группу %s",
"Unable to remove user from group %s" => "Невозможно удалить пользователя из группы %s",
"Couldn't update app." => "Невозможно обновить приложение",
"Wrong password" => "Неправильный пароль",
"No user supplied" => "Пользователь не задан",
"Please provide an admin recovery password, otherwise all user data will be lost" => "Пожалуйста введите администраторский пароль восстановления, иначе все пользовательские данные будут утеряны",
"Wrong admin recovery password. Please check the password and try again." => "Неправильный пароль восстановления. Проверьте пароль и попробуйте еще раз.",
"Back-end doesn't support password change, but the users encryption key was successfully updated." => "Используемый механизм не поддерживает смену паролей, но пользовательский ключ шифрования был успешно обновлён",
"Unable to change password" => "Невозможно изменить пароль",
"Sending..." => "Отправляется ...",
"User Documentation" => "Пользовательская документация",
"Admin Documentation" => "Документация администратора",
"Update to {appversion}" => "Обновить до {версия приложения}",
"Uninstall App" => "Удалить приложение",
"Disable" => "Выключить",
"Enable" => "Включить",
"Please wait...." => "Подождите...",
"Error while disabling app" => "Ошибка отключения приложения",
"Error while enabling app" => "Ошибка включения приложения",
"Updating...." => "Обновление...",
"Error while updating app" => "Ошибка при обновлении приложения",
"Error" => "Ошибка",
"Update" => "Обновить",
"Updated" => "Обновлено",
"Uninstalling ...." => "Удаление ...",
"Error while uninstalling app" => "Ошибка при удалении приложения.",
"Uninstall" => "Удалить",
"Select a profile picture" => "Выберите аватар",
"Very weak password" => "Очень слабый пароль",
"Weak password" => "Слабый пароль",
"So-so password" => "Так себе пароль",
"Good password" => "Хороший пароль",
"Strong password" => "Устойчивый к взлому пароль",
"Decrypting files... Please wait, this can take some time." => "Расшифровка файлов... Пожалуйста, подождите, это может занять некоторое время.",
"Delete encryption keys permanently." => "Перманентно удалить ключи шифрования. ",
"Restore encryption keys." => "Восстановить ключи шифрования.",
"Unable to delete {objName}" => "Невозможно удалить {objName}",
"Error creating group" => "Ошибка создания группы",
"A valid group name must be provided" => "Введите правильное имя группы",
"deleted {groupName}" => "удалено {groupName}",
"undo" => "отмена",
"Groups" => "Группы",
"Group Admin" => "Администратор группы",
"Delete" => "Удалить",
"never" => "никогда",
"deleted {userName}" => "удалён {userName}",
"add group" => "добавить группу",
"A valid username must be provided" => "Укажите правильное имя пользователя",
"Error creating user" => "Ошибка создания пользователя",
"A valid password must be provided" => "Укажите валидный пароль",
"Warning: Home directory for user \"{user}\" already exists" => "Предупреждение: домашняя папка пользователя \"{user}\" уже существует",
"__language_name__" => "Русский ",
"Everything (fatal issues, errors, warnings, info, debug)" => "Все (критические проблемы, ошибки, предупреждения, информационные, отладочные)",
"Info, warnings, errors and fatal issues" => "Информационные, предупреждения, ошибки и критические проблемы",
"Warnings, errors and fatal issues" => "Предупреждения, ошибки и критические проблемы",
"Errors and fatal issues" => "Ошибки и критические проблемы",
"Fatal issues only" => "Только критические проблемы",
"None" => "Нет новостей",
"Login" => "Логин",
"Plain" => "Простой",
"SSL" => "SSL",
"TLS" => "TLS",
"Security Warning" => "Предупреждение безопасности",
"You are accessing %s via HTTP. We strongly suggest you configure your server to require using HTTPS instead." => "Вы обращаетесь к %s используя HTTP. Мы настоятельно рекомендуем вам настроить сервер на использование HTTPS.",
"Your data directory and your files are probably accessible from the internet. The .htaccess file is not working. We strongly suggest that you configure your webserver in a way that the data directory is no longer accessible or you move the data directory outside the webserver document root." => "Похоже, что папка с Вашими данными и Ваши файлы доступны из интернета. Файл .htaccess не работает. Мы настойчиво предлагаем Вам сконфигурировать вебсервер таким образом, чтобы папка с Вашими данными более не была доступна или переместите папку с данными куда-нибудь в другое место вне основной папки документов вебсервера.",
"Setup Warning" => "Предупреждение установки",
"Your web server is not yet properly setup to allow files synchronization because the WebDAV interface seems to be broken." => "Веб-сервер до сих пор не настроен для возможности синхронизации файлов. Похоже что проблема в неисправности интерфейса WebDAV.",
"Please double check the <a href=\"%s\">installation guides</a>." => "Пожалуйста, дважды просмотрите <a href='%s'>инструкции по установке</a>.",
"This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." => "Возможно это вызвано кешем/ускорителем вроде Zend OPcache или eAccelerator.",
"Database Performance Info" => "Информация о производительности Базы Данных",
"SQLite is used as database. For larger installations we recommend to change this. To migrate to another database use the command line tool: 'occ db:convert-type'" => "В качестве Базы Данных используется SQLite. Для больших установок рекомендуется использовать другие типы Баз Данных. Чтобы переехать на другую Базу Данных используйте инструмент командной строки: 'ooc: db:conver-type'",
"Module 'fileinfo' missing" => "Модуль 'fileinfo' отсутствует",
"The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." => "PHP-модуль 'fileinfo' отсутствует. Мы настоятельно рекомендуем включить этот модуль для улучшения определения типов (mime-type) файлов.",
"Your PHP version is outdated" => "Ваша версия PHP устарела",
"Your PHP version is outdated. We strongly recommend to update to 5.3.8 or newer because older versions are known to be broken. It is possible that this installation is not working correctly." => "Ваша версия PHP устарела. Мы настоятельно рекомендуем  обновиться до 5.3.8 или новее,  так как старые версии работают не корректно. Вполне возможно, что эта установка не работает должным образом.",
"Locale not working" => "Локализация не работает",
"System locale can not be set to a one which supports UTF-8." => "Невозможно установить системную локаль, поддерживающую UTF-8",
"This means that there might be problems with certain characters in file names." => "Это значит, что могут быть проблемы с некоторыми символами в именах файлов.",
"We strongly suggest to install the required packages on your system to support one of the following locales: %s." => "Мы настоятельно рекомендуем установить требуемые пакеты в систему, для поддержки одной из следующих локалей: %s.",
"Internet connection not working" => "Интернет-соединение не работает",
"This server has no working internet connection. This means that some of the features like mounting of external storage, notifications about updates or installation of 3rd party apps don´t work. Accessing files from remote and sending of notification emails might also not work. We suggest to enable internet connection for this server if you want to have all features." => "Этот сервер не имеет подключения к сети интернет. Это значит, что некоторые возможности, такие как подключение внешних дисков, уведомления об обновлениях или установка сторонних приложений – не работают. Удалённый доступ к файлам и отправка уведомлений по электронной почте вероятнее всего тоже не будут работать. Предлагаем включить соединение с интернетом для этого сервера, если Вы хотите иметь все возможности.",
"Cron" => "Планировщик задач по расписанию",
"Last cron was executed at %s." => "Последняя cron-задача была запущена: %s.",
"Last cron was executed at %s. This is more than an hour ago, something seems wrong." => "Последняя cron-задача была запущена: %s. Это было больше часа назад, кажется что-то не так.",
"Cron was not executed yet!" => "Cron-задачи ещё не запускались!",
"Execute one task with each page loaded" => "Выполнять одно задание с каждой загруженной страницей",
"cron.php is registered at a webcron service to call cron.php every 15 minutes over http." => "cron.php зарегестрирован в webcron и будет вызываться каждые 15 минут по http.",
"Use system's cron service to call the cron.php file every 15 minutes." => "Использовать системный cron для вызова cron.php каждые 15 минут.",
"Sharing" => "Общий доступ",
"Allow apps to use the Share API" => "Позволить приложениям использовать API общего доступа",
"Allow users to share via link" => "Разрешить пользователям публикации через ссылки",
"Allow public uploads" => "Разрешить открытые загрузки",
"Set default expiration date" => "Установите дату окончания по-умолчанию",
"Expire after " => "Заканчивается после",
"days" => "дней",
"Allow resharing" => "Разрешить переоткрытие общего доступа",
"Restrict users to only share with users in their groups" => "Разрешить пользователям публикации только внутри их групп",
"Allow users to send mail notification for shared files" => "Разрешить пользователю оповещать почтой о расшаренных файлах",
"Exclude groups from sharing" => "Исключить группы из общего доступа",
"These groups will still be able to receive shares, but not to initiate them." => "Эти группы смогут получать общие файлы, но не смогут отправлять их.",
"Security" => "Безопасность",
"Enforce HTTPS" => "Принудить к HTTPS",
"Forces the clients to connect to %s via an encrypted connection." => "Принудить клиентов подключаться к %s через шифрованное соединение.",
"Please connect to your %s via HTTPS to enable or disable the SSL enforcement." => "Пожалуйста, подключитесь к %s используя HTTPS чтобы включить или отключить принудительное SSL.",
"Email Server" => "Сервер почты",
"This is used for sending out notifications." => "Используется для отправки уведомлений.",
"From address" => "Адрес отправителя",
"mail" => "почта",
"Authentication required" => "Требуется аутентификация ",
"Server address" => "Адрес сервера",
"Port" => "Порт",
"Credentials" => "Полномочия",
"SMTP Username" => "Имя пользователя",
"SMTP Password" => "Пароль",
"Test email settings" => "Тест настроек",
"Send email" => "Отправить сообщение",
"Log" => "Журнал",
"Log level" => "Уровень детализации журнала",
"More" => "Больше",
"Less" => "Меньше",
"Version" => "Версия",
"Developed by the <a href=\"http://ownCloud.org/contact\" target=\"_blank\">ownCloud community</a>, the <a href=\"https://github.com/owncloud\" target=\"_blank\">source code</a> is licensed under the <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a>." => "Разрабатывается <a href=\"http://ownCloud.org/contact\" target=\"_blank\">сообществом ownCloud</a>, <a href=\"https://github.com/owncloud\" target=\"_blank\">исходный код</a> доступен под лицензией <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a>.",
"Add your App" => "Добавить приложение",
"More Apps" => "Больше приложений",
"Select an App" => "Выберите приложение",
"Documentation:" => "Документация",
"See application page at apps.owncloud.com" => "Смотрите дополнения на apps.owncloud.com",
"See application website" => "См. сайт приложений",
"<span class=\"licence\"></span>-licensed by <span class=\"author\"></span>" => "<span class=\"licence\"></span> лицензия. Автор <span class=\"author\"></span>",
"Enable only for specific groups" => "Включить только для этих групп",
"All" => "Все",
"Administrator Documentation" => "Документация администратора",
"Online Documentation" => "Online документация",
"Forum" => "Форум",
"Bugtracker" => "Багтрекер",
"Commercial Support" => "Коммерческая поддержка",
"Get the apps to sync your files" => "Получить приложения для синхронизации ваших файлов",
"Show First Run Wizard again" => "Показать помощник настройки",
"You have used <strong>%s</strong> of the available <strong>%s</strong>" => "Вы использовали <strong>%s</strong> из доступных <strong>%s</strong>",
"Password" => "Пароль",
"Your password was changed" => "Ваш пароль изменён",
"Unable to change your password" => "Невозможно сменить пароль",
"Current password" => "Текущий пароль",
"New password" => "Новый пароль",
"Change password" => "Сменить пароль",
"Full Name" => "Полное имя",
"Email" => "E-mail",
"Your email address" => "Ваш адрес электронной почты",
"Fill in an email address to enable password recovery and receive notifications" => "Введите свой email-адрес для того, чтобы включить возможность восстановления пароля и получения уведомлений",
"Profile picture" => "Аватар",
"Upload new" => "Загрузить новый",
"Select new from Files" => "Выберите новый из файлов",
"Remove image" => "Удалить аватар",
"Either png or jpg. Ideally square but you will be able to crop it." => "Допустимые форматы: png и jpg. Если изображение не квадратное, то вам будет предложено обрезать его.",
"Your avatar is provided by your original account." => "Будет использован аватар вашей оригинальной учетной записи.",
"Cancel" => "Отменить",
"Choose as profile image" => "Установить как аватар",
"Language" => "Язык",
"Help translate" => "Помочь с переводом",
"The encryption app is no longer enabled, please decrypt all your files" => "Приложение для шифрования выключено, пожалуйста, расшифруйте ваши файлы",
"Log-in password" => "Пароль входа",
"Decrypt all Files" => "Снять шифрование со всех файлов",
"Your encryption keys are moved to a backup location. If something went wrong you can restore the keys. Only delete them permanently if you are sure that all files are decrypted correctly." => "Ваши ключи шифрования были архивированы. Если что-то пойдёт не так, вы сможете восстановить ключи. Удаляйте ключи из архива только тогда, когда вы будете уверены, что все файлы были успешно расшифрованы.",
"Restore Encryption Keys" => "Восстановить Ключи Шифрования",
"Delete Encryption Keys" => "Удалить Ключи Шифрования",
"Login Name" => "Имя пользователя",
"Create" => "Создать",
"Admin Recovery Password" => "Восстановление пароля администратора",
"Enter the recovery password in order to recover the users files during password change" => "Введите пароль для того, чтобы восстановить файлы пользователей при смене пароля",
"Search Users and Groups" => "Искать пользователей и групп",
"Add Group" => "Добавить группу",
"Group" => "Группа",
"Everyone" => "Все",
"Admins" => "Администраторы",
"Default Quota" => "Квота по умолчанию",
"Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" => "Пожалуйста, введите квоту на хранилище (например: \"512 MB\" или \"12 GB\")",
"Unlimited" => "Неограниченно",
"Other" => "Другое",
"Username" => "Имя пользователя",
"Quota" => "Квота",
"Storage Location" => "Место хранилища",
"Last Login" => "Последний вход",
"change full name" => "изменить полное имя",
"set new password" => "установить новый пароль",
"Default" => "По умолчанию",
"Connectivity Checks" => "Проверка соединения",
"No problems found" => "Проблемы не найдены",
);
$PLURAL_FORMS = "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);";
